/*
*******************************************************************************************************************
*												BLINK LED DEMO
* Description:  The first demo program for PIC18LF4550-Eval-Rev4a eval board to blink LED1 to LED4 connected to 
*				OUT0(RD0) to OUT3(RD3) output of latch device 74HC573.
*				Therefore RD0 controls LED1, RD1 controls LED2, RD2 controls LED3, and RD3 controls LED4.
*				Because LEDs wired to output of latch device 74HC573, we need two control pins RC0(LE) and RC1(/OE)
*				to use RDx for LED output. 
*				
* File:			..\Hello_World\main.c
* Dependency:	..\Hello_World\18f4550i.lkr
* Software:		C18 Student version under MPLAB 7.60 IDE
* Programmer: 	John Leung, TechToys Co. (www.TechToys.com.hk)
* Hardware:		PIC18LF4550-Eval-Rev4a development board
* Date:			17th April 2008
* Version:		1.0
* Programmer:	John Leung (www.TechToys.com.hk)
* Remarks:		
*******************************************************************************************************************
*/

#include <p18cxxx.h>
#include <delays.h>

/*
********************************************************************************************************************
*												Pragma Section
*
* Configuration bits under MPLAB v7.41 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Note: Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* 		variables available
********************************************************************************************************************
*/
#pragma config FOSC   = HS			// HS oscillator
#pragma config CPUDIV = OSC4_PLL6	// OSC postscaler of 4 => instruction cycle at 1.2MHz (20MHz/4/4) 
#pragma config PWRT   = ON			// PowerUp timer ON
#pragma config WDT    = OFF			// watchdog timer off
#pragma config LVP    = OFF			// low level voltage OFF
#pragma config BOR    = OFF			// brown out detect OFF
#pragma config DEBUG  = ON			// Debug ON
#pragma config VREGEN = OFF			// Disable internal 3.3V regulator!
#pragma config PBADEN = OFF 		// PORTB<4:0> as digital IO on reset

/*
********************************************************************************************************************
*													MAIN
********************************************************************************************************************
*/
unsigned char counter;

void main(void)
{
	ADCON1 = 0x0F;								//PORTA all digital operation
	TRISCbits.TRISC2 = 0;						//set RC2 an output
	LATD = 0x00;								//use LED1 - LED4 as a simple counter
	TRISD = 0x00; 								//configure PORTD for output

	//For PIC18LF4550-Eval-Rev4A hardware with 74HC573 latch
	TRISCbits.TRISC0 = 0;
	LATCbits.LATC0  = 1;						//un-latch 74HC573 to make OUTD follows LATD
	TRISCbits.TRISC1 = 0;						//enable the latch
	LATCbits.LATC1 = 0;

	while(1)
	{
			for(counter = 0 ; counter <16; counter++){
			LATD = counter;
			Delay100TCYx(200);					//software delay 100*200 machine cycle=>20,000*(0.8us)=16ms
												//dependency: delays.h under ..\mcc18\h
			}
					
	}
}
